import winston, { format } from "winston";
import Transport from "winston-transport";
import zlib from "zlib";
/**
 * 环境变量判断，用于确定是否为生产环境
 * 非 'dev' 环境被视为生产环境
 */
const isProd = process.env.NODE_ENV !== "dev";
/**
 * OpenObserve HTTP传输器
 * 用于将日志数据发送到 OpenObserve 服务器
 * @class OpenObserveTransport
 * @extends Transport
 */
class OpenObserveTransport extends Transport {
    host;
    port;
    uri;
    username;
    password;
    tls;
    /**
     * 构造函数
     * @param {OpenObserveTransportOptions} opts - 传输器配置选项
     */
    constructor(opts) {
        super(opts);
        this.host = opts.host;
        this.port = opts.port;
        this.uri = opts.uri;
        this.username = opts.username;
        this.password = opts.password;
        this.tls = opts.tls !== false;
    }
    /**
     * 日志处理方法，将日志发送到 OpenObserve 服务器
     * @param {Record<string, any>} info - 日志信息
     * @param {() => void} callback - 回调函数
     * @returns {Promise<void>}
     */
    async log(info, callback) {
        // 异步通知日志已被记录
        setImmediate(() => {
            this.emit("logged", info);
        });
        try {
            // 添加时间戳字段和环境变量到日志数据
            const logData = {
                ...info,
                _timestamp: new Date().toISOString(),
                env: process.env.NODE_ENV || "unknown",
            };
            // 压缩数据以减少传输大小
            const compressedData = await new Promise((resolve, reject) => {
                zlib.gzip(JSON.stringify(logData), (err, result) => {
                    if (err)
                        reject(err);
                    else
                        resolve(result);
                });
            });
            // 构建目标 URL
            const protocol = this.tls ? "https" : "http";
            const url = `${protocol}://${this.host}:${this.port}${this.uri}`;
            // 使用 fetch 替代 axios 发送数据到 OpenObserve
            const response = await fetch(url, {
                method: "POST",
                headers: {
                    "Content-Type": "application/json",
                    "Content-Encoding": "gzip",
                    "X-Midun-Idc-Token": "ff95924e0fba11f0a09ae4434b919620",
                    Authorization: `Basic ${Buffer.from(`${this.username}:${this.password}`).toString("base64")}`,
                },
                body: compressedData,
            });
            // 检查响应状态
            if (!response.ok) {
                throw new Error(`OpenObserve 响应错误: ${response.status} ${response.statusText}`);
            }
        }
        catch (error) {
            console.error("向 OpenObserve 发送日志时出错:", error);
        }
        // 执行回调，表示处理完成
        callback();
    }
}
/**
 * 日志传输器列表
 * 包含控制台输出和 OpenObserve 传输器
 */
const transports = [
    // 控制台传输器，生产环境使用 info 级别，开发环境使用 silly 级别
    new winston.transports.Console({
        level: isProd ? "info" : "silly",
    }),
    // OpenObserve 传输器配置
    new OpenObserveTransport({
        level: "silly",
        host: "lark-egg-ob-preview.ai.xiaomi.com",
        port: 443,
        uri: "/api/default/default/_json",
        username: "zhaoyingbo@live.cn",
        password: "GI81PQiPQvHtRBMV",
        tls: true,
    }),
];
/**
 * 日志格式化处理列表
 * 定义日志的输出格式
 */
const formatList = [
    format.simple(), // 简单文本格式化
    format.timestamp({ format: "YYYY-MM-DD HH:mm:ss" }), // 添加格式化的时间戳
    format.json(), // JSON 格式输出
];
/**
 * 创建并配置 Winston 日志记录器
 * @type {winston.Logger}
 */
const logger = winston.createLogger({
    level: "silly", // 设置最低日志级别
    format: format.combine.apply(null, formatList), // 应用格式化处理器
    transports, // 设置传输器
});
export default logger;
//# sourceMappingURL=index.js.map